@@ -87,8 +87,7 @@ plot.fast <- function (x, choix = "ind", axes = c(1, 2), xlim = NULL, ylim = NUL
         else sub.titre <- "SortingTask factor map"
         if (is.na(test.invisible[1]) | is.na(test.invisible[2]) |
             is.na(test.invisible[4]) | is.na(test.invisible[5])) {
-            if (new.plot)
-                dev.new()
+            if (new.plot & (!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY")))) dev.new()
             plot(0, 0, main = titre, xlab = paste("Dim ", axes[1],
                 " (", signif(res.mca$eig[axes[1], 2], 4), "%)",
                 sep = ""), ylab = paste("Dim ", axes[2], " (",
@@ -121,8 +120,7 @@ plot.fast <- function (x, choix = "ind", axes = c(1, 2), xlim = NULL, ylim = NUL
     }
     group = nrow(res.mca$group$coord)
     if (choix == "group") {
-        if (new.plot)
-            dev.new()
+        if (new.plot & (!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY")))) dev.new()
         if (is.null(title))
             title <- "Consumers representation"
         else sub.title <- "Consumers representation"
